@@ -1,7 +1,7 @@
 package Perinci::CmdLine::Classic::Role::Help;
 
-our $DATE = '2015-02-06'; # DATE
-our $VERSION = '1.45'; # VERSION
+our $DATE = '2015-02-26'; # DATE
+our $VERSION = '1.46'; # VERSION
 
 # split here just so it's more organized
 
@@ -258,8 +258,8 @@ sub help_section_subcommands {
     my ($self, $r) = @_;
 
     my $verbose = $r->{_help_verbose};
-    my $scs = $self->subcommands;
-    return unless $scs && !$r->{subcommand_name};
+    return unless $self->subcommands && !$r->{subcommand_name};
+    my $scs = $self->list_subcommands;
 
     my @scs = sort keys %$scs;
     my @shown_scs;
@@ -511,7 +511,7 @@ Perinci::CmdLine::Classic::Role::Help - Help-related routines
 
 =head1 VERSION
 
-This document describes version 1.45 of Perinci::CmdLine::Classic::Role::Help (from Perl distribution Perinci-CmdLine-Classic), released on 2015-02-06.
+This document describes version 1.46 of Perinci::CmdLine::Classic::Role::Help (from Perl distribution Perinci-CmdLine-Classic), released on 2015-02-26.
 
 =for Pod::Coverage ^(.+)$
 
